# consensusGen

`consensusGen` is a Python code implementing an genetic algorithm allowing to build a consensus value from measurement results of an inter-laboratory comparison. 

The code is developped and maintained by the BIPM (MIT license).